#ifndef _STRACE_H
#define _STRACE_H

//
// The maximum number of elements in the stack context
//
#define MAX_STACK_ELEMENTS 20

//
// Encapsulates the state at the time that a system call occurs
//
typedef struct _SYSTEM_CALL_EVENT
{
	//
	// The system call event that occurred
	//
	ULONG SystemCallNumber;

	//
	// The name of the system call
	//
	PWSTR SystemCallName;

	//
	// The unique hash code of the system call name
	//
	ULONG SystemCallHash;

	//
	// The arguments that were passed to the system call
	//
	PULONG_PTR Arguments;

	//
	// The number of arguments 
	//
	ULONG NumberOfArguments;

	//
	// The identifier of the thread that made the system call
	//
	ULONG ThreadId;

	//
	// A handle to the thread that the system call occurred in
	//
	HANDLE ThreadHandle;

	//
	// The register state at the time that the system call occurred
	//
	PCONTEXT ThreadContext;

	//
	// A handle to the process that triggered the system call
	//
	HANDLE ProcessHandle;

	//
	// User context that was returned from InitializePlugin
	//
	PVOID PluginContext;

	//
	// TRUE if this event was suppressed
	//
	BOOL Suppressed;

} SYSTEM_CALL_EVENT, *PSYSTEM_CALL_EVENT;

//
// Encapsulates the state at the time that a system call returns
//
typedef struct _SYSTEM_CALL_RETURN_EVENT
{
	//
	// A pointer to the system call
	//
	PSYSTEM_CALL_EVENT SystemCall;

	//
	// The status code returned by the system call
	//
	LONG Status;

} SYSTEM_CALL_RETURN_EVENT, *PSYSTEM_CALL_RETURN_EVENT;

#endif
